Core
----

Problematic
^^^^^^^^^^^

How can we get started?

Documentation
^^^^^^^^^^^^^

.. automodule:: PyFunceble.core
   :members:
   :private-members:


:code:`APICore()`
"""""""""""""""""

.. autoclass:: PyFunceble.core.api.APICore
    :members:
    :private-members:

:code:`CLICore()`
"""""""""""""""""

.. autoclass:: PyFunceble.core.cli.CLICore
    :members:
    :private-members:

:code:`FileCore()`
""""""""""""""""""

.. autoclass:: PyFunceble.core.file.FileCore
    :members:
    :private-members:

:code:`OurProcessWrapper()`
"""""""""""""""""""""""""""

.. autoclass:: PyFunceble.core.multiprocess.OurProcessWrapper
    :members:
    :private-members:

:code:`MultiprocessCore()`
""""""""""""""""""""""""""

.. autoclass:: PyFunceble.core.multiprocess.MultiprocessCore
    :members:
    :private-members:

:code:`SimpleCore()`
""""""""""""""""""""

.. autoclass:: PyFunceble.core.simple.SimpleCore
    :members:
    :private-members:

